==> nivo-0.6.0.tgz: package/es/components/charts/radial-stack/RadialStackRadiusAxis.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import d3 from 'd3';
import invariant from 'invariant';
import { radiansToDegrees } from '../../../ArcUtils';

var RadialStackRadiusAxis = function (_Component) {
    _inherits(RadialStackRadiusAxis, _Component);

    function RadialStackRadiusAxis() {
        _classCallCheck(this, RadialStackRadiusAxis);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    RadialStackRadiusAxis.decorateRadialStack = function decorateRadialStack(_ref) {
        var angleData = _ref.props.angleData;

        var axis = d3.svg.axis();

        return function (_ref2) {
            var element = _ref2.element,
                angle = _ref2.angle,
                radius = _ref2.radius,
                transitionDuration = _ref2.transitionDuration,
                transitionEasing = _ref2.transitionEasing;

            var wrapper = d3.select('.nivo_radial-stack_radius-axis-' + angleData);
            if (wrapper.node() === null) {
                wrapper = element.append('g').attr('class', 'nivo_radial-stack_radius-axis nivo_radial-stack_radius-axis-' + angleData);
            }

            // copy original scale
            var scale = radius.copy();
            axis.scale(scale).ticks(3);

            wrapper.attr('transform', function (d) {
                return 'rotate(' + radiansToDegrees(angle(angleData)) + ')';
            });

            wrapper.transition().duration(transitionDuration).ease(transitionEasing).call(axis);
        };
    };

    RadialStackRadiusAxis.prototype.render = function render() {
        invariant(false, '<RadialStackRadiusAxis> element is for Radial components configuration only and should not be rendered');
    };

    return RadialStackRadiusAxis;
}(Component);

var any = PropTypes.any;


RadialStackRadiusAxis.propTypes = {
    angleData: any.isRequired
};

RadialStackRadiusAxis.defaultProps = {};

export default RadialStackRadiusAxis;

==> nivo-0.15.0.tgz: package/es/components/charts/radial-stack/RadialStackRadiusAxis.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import d3 from 'd3';
import invariant from 'invariant';
import { radiansToDegrees } from '../../../lib/arcUtils';

var RadialStackRadiusAxis = function (_Component) {
    _inherits(RadialStackRadiusAxis, _Component);

    function RadialStackRadiusAxis() {
        _classCallCheck(this, RadialStackRadiusAxis);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    RadialStackRadiusAxis.decorateRadialStack = function decorateRadialStack(_ref) {
        var angleData = _ref.props.angleData;

        var axis = d3.svg.axis();

        return function (_ref2) {
            var element = _ref2.element,
                angle = _ref2.angle,
                radius = _ref2.radius,
                transitionDuration = _ref2.transitionDuration,
                transitionEasing = _ref2.transitionEasing;

            var wrapper = d3.select('.nivo_radial-stack_radius-axis-' + angleData);
            if (wrapper.node() === null) {
                wrapper = element.append('g').attr('class', 'nivo_radial-stack_radius-axis nivo_radial-stack_radius-axis-' + angleData);
            }

            // copy original scale
            var scale = radius.copy();
            axis.scale(scale).ticks(3);

            wrapper.attr('transform', function (d) {
                return 'rotate(' + radiansToDegrees(angle(angleData)) + ')';
            });

            wrapper.transition().duration(transitionDuration).ease(transitionEasing).call(axis);
        };
    };

    RadialStackRadiusAxis.prototype.render = function render() {
        invariant(false, '<RadialStackRadiusAxis> element is for Radial components configuration only and should not be rendered');
    };

    return RadialStackRadiusAxis;
}(Component);

var any = PropTypes.any;


RadialStackRadiusAxis.propTypes = {
    angleData: any.isRequired
};

RadialStackRadiusAxis.defaultProps = {};

export default RadialStackRadiusAxis;
